@@ -60,6 +60,11 @@ class AxisDirection : public util::CodeList {
     valueOf(const std::string &nameIn) noexcept;
     //! @endcond
 
+    AxisDirection(const AxisDirection &) = delete;
+    AxisDirection &operator=(const AxisDirection &) = delete;
+    AxisDirection(AxisDirection &&) = delete;
+    AxisDirection &operator=(AxisDirection &&) = delete;
+
     PROJ_DLL static const AxisDirection NORTH;
     PROJ_DLL static const AxisDirection NORTH_NORTH_EAST;
     PROJ_DLL static const AxisDirection NORTH_EAST;
@@ -110,6 +115,34 @@ class AxisDirection : public util::CodeList {
 
 // ---------------------------------------------------------------------------
 
+/** \brief Meaning of the axis value range specified through minimumValue and
+ * maximumValue
+ *
+ * \remark Implements RangeMeaning from \ref ISO_19111_2019
+ * \since 9.2
+ */
+class RangeMeaning : public util::CodeList {
+  public:
+    //! @cond Doxygen_Suppress
+    PROJ_DLL static const RangeMeaning *
+    valueOf(const std::string &nameIn) noexcept;
+    //! @endcond
+
+    PROJ_DLL static const RangeMeaning EXACT;
+    PROJ_DLL static const RangeMeaning WRAPAROUND;
+
+  protected:
+    friend class util::optional<RangeMeaning>;
+    RangeMeaning();
+
+  private:
+    explicit RangeMeaning(const std::string &nameIn);
+
+    static std::map<std::string, const RangeMeaning *> registry;
+};
+
+// ---------------------------------------------------------------------------
+
 class Meridian;
 /** Shared pointer of Meridian. */
 using MeridianPtr = std::shared_ptr<Meridian>;
@@ -181,6 +214,7 @@ class PROJ_GCC_DLL CoordinateSystemAxis final : public common::IdentifiedObject,
     PROJ_DLL const common::UnitOfMeasure &unit() PROJ_PURE_DECL;
     PROJ_DLL const util::optional<double> &minimumValue() PROJ_PURE_DECL;
     PROJ_DLL const util::optional<double> &maximumValue() PROJ_PURE_DECL;
+    PROJ_DLL const util::optional<RangeMeaning> &rangeMeaning() PROJ_PURE_DECL;
     PROJ_DLL const MeridianPtr &meridian() PROJ_PURE_DECL;
 
     // Non-standard
@@ -190,6 +224,15 @@ class PROJ_GCC_DLL CoordinateSystemAxis final : public common::IdentifiedObject,
            const common::UnitOfMeasure &unitIn,
            const MeridianPtr &meridianIn = nullptr);
 
+    PROJ_DLL static CoordinateSystemAxisNNPtr
+    create(const util::PropertyMap &properties,
+           const std::string &abbreviationIn, const AxisDirection &directionIn,
+           const common::UnitOfMeasure &unitIn,
+           const util::optional<double> &minimumValueIn,
+           const util::optional<double> &maximumValueIn,
+           const util::optional<RangeMeaning> &rangeMeaningIn,
+           const MeridianPtr &meridianIn = nullptr);
+
     PROJ_PRIVATE :
 
         //! @cond Doxygen_Suppress
@@ -323,13 +366,16 @@ class PROJ_GCC_DLL SphericalCS final : public CoordinateSystem {
            const CoordinateSystemAxisNNPtr &axis1,
            const CoordinateSystemAxisNNPtr &axis2);
 
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE = "spherical";
+
   protected:
     PROJ_INTERNAL explicit SphericalCS(
         const std::vector<CoordinateSystemAxisNNPtr> &axisIn);
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string getWKT2Type(bool) const override {
-        return "spherical";
+        return WKT2_TYPE;
     }
 
   private:
@@ -384,6 +430,9 @@ class PROJ_GCC_DLL EllipsoidalCS final : public CoordinateSystem {
         const common::UnitOfMeasure &angularUnit,
         const common::UnitOfMeasure &linearUnit);
 
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE = "ellipsoidal";
+
     //! @cond Doxygen_Suppress
 
     /** \brief Typical axis order. */
@@ -416,7 +465,7 @@ class PROJ_GCC_DLL EllipsoidalCS final : public CoordinateSystem {
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string getWKT2Type(bool) const override {
-        return "ellipsoidal";
+        return WKT2_TYPE;
     }
 
   protected:
@@ -452,6 +501,9 @@ class PROJ_GCC_DLL VerticalCS final : public CoordinateSystem {
     PROJ_DLL static VerticalCSNNPtr
     createGravityRelatedHeight(const common::UnitOfMeasure &unit);
 
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE = "vertical";
+
     PROJ_PRIVATE :
         //! @cond Doxygen_Suppress
         PROJ_INTERNAL VerticalCSNNPtr
@@ -464,7 +516,7 @@ class PROJ_GCC_DLL VerticalCS final : public CoordinateSystem {
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string getWKT2Type(bool) const override {
-        return "vertical";
+        return WKT2_TYPE;
     }
 
   private:
@@ -522,6 +574,10 @@ class PROJ_GCC_DLL CartesianCS final : public CoordinateSystem {
     PROJ_DLL static CartesianCSNNPtr
     createGeocentric(const common::UnitOfMeasure &unit);
 
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE =
+        "Cartesian"; // uppercase is intended
+
     PROJ_PRIVATE :
         //! @cond Doxygen_Suppress
         PROJ_INTERNAL CartesianCSNNPtr
@@ -535,7 +591,7 @@ class PROJ_GCC_DLL CartesianCS final : public CoordinateSystem {
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string getWKT2Type(bool) const override {
-        return "Cartesian"; // uppercase is intended
+        return WKT2_TYPE;
     }
 
   private:
@@ -544,6 +600,59 @@ class PROJ_GCC_DLL CartesianCS final : public CoordinateSystem {
 
 // ---------------------------------------------------------------------------
 
+class AffineCS;
+/** Shared pointer of AffineCS. */
+using AffineCSPtr = std::shared_ptr<AffineCS>;
+/** Non-null shared pointer of AffineCS. */
+using AffineCSNNPtr = util::nn<AffineCSPtr>;
+
+/** \brief A two- or three-dimensional coordinate system in Euclidean space
+ * with straight axes that are not necessarily orthogonal.
+ *
+ * \remark Implements AffineCS from \ref ISO_19111_2019
+ * \since 9.2
+ */
+class PROJ_GCC_DLL AffineCS final : public CoordinateSystem {
+  public:
+    //! @cond Doxygen_Suppress
+    PROJ_DLL ~AffineCS() override;
+    //! @endcond
+
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE = "affine";
+
+    PROJ_DLL static AffineCSNNPtr
+    create(const util::PropertyMap &properties,
+           const CoordinateSystemAxisNNPtr &axis1,
+           const CoordinateSystemAxisNNPtr &axis2);
+    PROJ_DLL static AffineCSNNPtr
+    create(const util::PropertyMap &properties,
+           const CoordinateSystemAxisNNPtr &axis1,
+           const CoordinateSystemAxisNNPtr &axis2,
+           const CoordinateSystemAxisNNPtr &axis3);
+
+    PROJ_PRIVATE :
+        //! @cond Doxygen_Suppress
+        PROJ_INTERNAL AffineCSNNPtr
+        alterUnit(const common::UnitOfMeasure &unit) const;
+
+    //! @endcond
+
+  protected:
+    PROJ_INTERNAL explicit AffineCS(
+        const std::vector<CoordinateSystemAxisNNPtr> &axisIn);
+    INLINED_MAKE_SHARED
+
+    PROJ_INTERNAL std::string getWKT2Type(bool) const override {
+        return WKT2_TYPE;
+    }
+
+  private:
+    AffineCS(const AffineCS &other) = delete;
+};
+
+// ---------------------------------------------------------------------------
+
 class OrdinalCS;
 /** Shared pointer of OrdinalCS. */
 using OrdinalCSPtr = std::shared_ptr<OrdinalCS>;
@@ -567,13 +676,16 @@ class PROJ_GCC_DLL OrdinalCS final : public CoordinateSystem {
     create(const util::PropertyMap &properties,
            const std::vector<CoordinateSystemAxisNNPtr> &axisIn);
 
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE = "ordinal";
+
   protected:
     PROJ_INTERNAL explicit OrdinalCS(
         const std::vector<CoordinateSystemAxisNNPtr> &axisIn);
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string getWKT2Type(bool) const override {
-        return "ordinal";
+        return WKT2_TYPE;
     }
 
   private:
@@ -603,13 +715,16 @@ class PROJ_GCC_DLL ParametricCS final : public CoordinateSystem {
     create(const util::PropertyMap &properties,
            const CoordinateSystemAxisNNPtr &axisIn);
 
+    /** Value of getWKT2Type() */
+    static constexpr const char *WKT2_TYPE = "parametric";
+
   protected:
     PROJ_INTERNAL explicit ParametricCS(
         const std::vector<CoordinateSystemAxisNNPtr> &axisIn);
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string getWKT2Type(bool) const override {
-        return "parametric";
+        return WKT2_TYPE;
     }
 
   private:
@@ -637,6 +752,9 @@ class PROJ_GCC_DLL TemporalCS : public CoordinateSystem {
     PROJ_DLL ~TemporalCS() override;
     //! @endcond
 
+    /** WKT2:2015 type */
+    static constexpr const char *WKT2_2015_TYPE = "temporal";
+
   protected:
     PROJ_INTERNAL explicit TemporalCS(const CoordinateSystemAxisNNPtr &axis);
     INLINED_MAKE_SHARED
@@ -675,6 +793,9 @@ class PROJ_GCC_DLL DateTimeTemporalCS final : public TemporalCS {
     create(const util::PropertyMap &properties,
            const CoordinateSystemAxisNNPtr &axis);
 
+    /** WKT2:2019 type */
+    static constexpr const char *WKT2_2019_TYPE = "TemporalDateTime";
+
   protected:
     PROJ_INTERNAL explicit DateTimeTemporalCS(
         const CoordinateSystemAxisNNPtr &axis);
@@ -711,6 +832,9 @@ class PROJ_GCC_DLL TemporalCountCS final : public TemporalCS {
     create(const util::PropertyMap &properties,
            const CoordinateSystemAxisNNPtr &axis);
 
+    /** WKT2:2019 type */
+    static constexpr const char *WKT2_2019_TYPE = "TemporalCount";
+
   protected:
     PROJ_INTERNAL explicit TemporalCountCS(
         const CoordinateSystemAxisNNPtr &axis);
@@ -747,6 +871,9 @@ class PROJ_GCC_DLL TemporalMeasureCS final : public TemporalCS {
     create(const util::PropertyMap &properties,
            const CoordinateSystemAxisNNPtr &axis);
 
+    /** WKT2:2019 type */
+    static constexpr const char *WKT2_2019_TYPE = "TemporalMeasure";
+
   protected:
     PROJ_INTERNAL explicit TemporalMeasureCS(
         const CoordinateSystemAxisNNPtr &axis);
